California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 50 - WATER QUALITY, SUPPLY AND SAFE DRINKING WATER PROJECTS. COASTAL WETLANDS PURCHASE AND PROTECTION. BONDS. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1245318 | YES ON 50. COALITION OF CONSERVATIONISTS, BUSINESS, WATER & ENGINEERING COS., OWNERS OF OPEN SPACE. | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1245176 | CALIFORNIAN'S FOR FISCAL RESTRAINT, NO ON PROPOSITION 50 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1245164 | PCL'S YES ON 50 AND 51 COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1241134 | YES ON 50, CALIFORNIANS FOR SAFE, CLEAN WATER, FUNDED BY PACS AND ORGANIZATIONS ESTABLISHED TO PROTECT THE ENVIRONMENT CONSERVATION GROUPS, AND OWNERS OF OPEN SPACE | SUPPORT